# ozi-templates CHANGELOG
## 2.9.0 (2024-08-22)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d269c50`](https://github.com/OZI-Project/ozi-templates/commit/d269c5028d6d902592d69380736789f7255362c6))

*  Bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b3aa25d`](https://github.com/OZI-Project/ozi-templates/commit/b3aa25d0a9a75496d35259e58c85283115067a77))

*  Bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f4172eb60419c98b5cf18c89d78cde8b553f5d15...7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ad95a4c`](https://github.com/OZI-Project/ozi-templates/commit/ad95a4c15700fce190a95eeb88e17784b53d13db))

*  Bump github/codeql-action from 3.26.2 to 3.26.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.2 to 3.26.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/429e1977040da7a23b6822b13c129cd1ba93dbb2...f0f3afee809481da311ca3a6ff1ff51d81dbeb24)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7aae05e`](https://github.com/OZI-Project/ozi-templates/commit/7aae05e71655c12697439ec94b451d5d726c27b8))

*  Bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`72f3f10`](https://github.com/OZI-Project/ozi-templates/commit/72f3f10c2c98a7b3363a0e67e62a8e12b8bd8012))


### ✨ Implemented Features

*  update for OZI spec 0.8

Simplified build-system requires using OZI.build 1.2 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`feb6b07`](https://github.com/OZI-Project/ozi-templates/commit/feb6b075c1a76f265432d63a980cc7de6adc1af8))

## 2.8.2 (2024-08-18)


### 🐛 Fixed Bugs

* ✏️ use whole compile-requirements-command array — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`cd15dda`](https://github.com/OZI-Project/ozi-templates/commit/cd15dda8487ab702aff43cc72d7c03660b9d6e10))

## 2.8.1 (2024-08-18)


### 🐛 Fixed Bugs

*  fix compile requirements command finding — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3a57da2`](https://github.com/OZI-Project/ozi-templates/commit/3a57da220276c804482be42a30f9592a4ed9269a))

## 2.8.0 (2024-08-16)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.1 to 3.26.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.1 to 3.26.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/29d86d22a34ea372b1bbf3b2dced2e25ca6b3384...429e1977040da7a23b6822b13c129cd1ba93dbb2)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e5b620c`](https://github.com/OZI-Project/ozi-templates/commit/e5b620c061b3256511de2e2c72821af6488484a3))


### 🔨 Updated Scripts

*  expect ``project.enable_uv`` boolean — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`5874996`](https://github.com/OZI-Project/ozi-templates/commit/58749961b3f1eb0005ca6aed697f505299d8d3c4))


### ✨ Implemented Features

* 🔨 add cibuildwheel config template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`180cefd`](https://github.com/OZI-Project/ozi-templates/commit/180cefde57a11af559c141e0a2685a7e0040dea5))

## 2.7.1 (2024-08-15)


### 🐛 Fixed Bugs

*  fix tox invoke path and options — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c9d72a2`](https://github.com/OZI-Project/ozi-templates/commit/c9d72a2785b9cf8877bf9524bf1654f9b8099cde))

## 2.7.0 (2024-08-15)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.0 to 3.26.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.0 to 3.26.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/eb055d739abdc2e8de2e5f4ba1a8b246daa779aa...29d86d22a34ea372b1bbf3b2dced2e25ca6b3384)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`69a67a9`](https://github.com/OZI-Project/ozi-templates/commit/69a67a9aeedc9f484c002bb9f3601125a8d1debe))

*  Bump OZI-Project/release from 0.8.7 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.7 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3280088d580a25abdecd35ebb022d4529af6a995...f4172eb60419c98b5cf18c89d78cde8b553f5d15)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8ced9a8`](https://github.com/OZI-Project/ozi-templates/commit/8ced9a887472a40d9b25754778a48512bc5862f8))

*  Bump OZI-Project/release from 0.8.4 to 0.8.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.4 to 0.8.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0ca87b5495c672f0d0c5ceaa6508e631a5c051f9...3280088d580a25abdecd35ebb022d4529af6a995)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b246ad2`](https://github.com/OZI-Project/ozi-templates/commit/b246ad2484ce8233affade7aa72eed0ff6cf7125))


### ✨ Implemented Features

*  add expectation for project namespace to set ``--github-harden-runner`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8489091`](https://github.com/OZI-Project/ozi-templates/commit/8489091eb78ae90aea1e8546e0e152feb0446f79))

*  add ``tox -e invoke [release|publish]`` template for local CI/CD — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b743496`](https://github.com/OZI-Project/ozi-templates/commit/b74349603e5e072b30c61a59523b37b9da205820))

## 2.6.4 (2024-08-09)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release@0.8.4 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`61f7c88`](https://github.com/OZI-Project/ozi-templates/commit/61f7c881b4e6d2d3905f6b374251c665ce245d07))

## 2.6.3 (2024-08-09)


### 🔨 Updated Scripts

*  Update ozi.yml:release endpoint allow list for 0.8.x — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`5f7e9ad`](https://github.com/OZI-Project/ozi-templates/commit/5f7e9ad22a0534809630313e20ab1a4d4c0d28f6))

## 2.6.2 (2024-08-09)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.15 to 3.26.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.15 to 3.26.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/afb54ba388a7dca6ecae48f608c4ff05ff4cc77a...eb055d739abdc2e8de2e5f4ba1a8b246daa779aa)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`561f5f3`](https://github.com/OZI-Project/ozi-templates/commit/561f5f3ee9c340398d0647b6e5533b7c9519c02f))

*  Bump actions/upload-artifact from 4.3.5 to 4.3.6

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.5 to 4.3.6.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/89ef406dd8d7e03cfd12d9e0a4a378f454709029...834a144ee995460fba8ed112a2fc961b36a5ec5a)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9df90ef`](https://github.com/OZI-Project/ozi-templates/commit/9df90efbdc619b4cf160e890fa327dc3a0139277))

*  Bump OZI-Project/release from 0.7.4 to 0.8.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`e58783f`](https://github.com/OZI-Project/ozi-templates/commit/e58783f46a7e845042e2b0ee8917aa3cab5e6797))

## 2.6.1 (2024-08-07)


### 🚸 Improved Usability

*  add python 3.13 to supported versions

note that this support is untested — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`61d5329`](https://github.com/OZI-Project/ozi-templates/commit/61d532907dd59d22e36344582997b30830b06454))

## 2.6.0 (2024-08-07)


### 🔥 Deleted Code or Files

*  remove ``filter.sha256sum`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6aa7c08`](https://github.com/OZI-Project/ozi-templates/commit/6aa7c08686e11b3789d407c7d8bd5d40a0bd2f70))


### ➖ Removed Dependencies

*  requests — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2b6e389`](https://github.com/OZI-Project/ozi-templates/commit/2b6e3899d166cbfddd86f54c050623b889ccea4f))


### ✏️ Corrected Typos

*  remove requests import — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`08243ed`](https://github.com/OZI-Project/ozi-templates/commit/08243ede0041279740958e0e0f87500acc43fd00))


### ✨ Implemented Features

*  beta release — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b78eb85`](https://github.com/OZI-Project/ozi-templates/commit/b78eb851053fe7f684725cbec629fe9305b86458))

## 2.5.8 (2024-08-05)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e381013`](https://github.com/OZI-Project/ozi-templates/commit/e381013ccbbfa044b4bf12a8ae94a3e7632685bb))

*  Bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`4ff93ff`](https://github.com/OZI-Project/ozi-templates/commit/4ff93ffdadc3f7b2d3fd82c3f25c3e57e78b6824))

*  Bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ea8786d`](https://github.com/OZI-Project/ozi-templates/commit/ea8786d5489d126254168e01254fdf5c30436785))

*  Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`fe105e3`](https://github.com/OZI-Project/ozi-templates/commit/fe105e3ab418f7ed9d60507413c7f4f6e7018261))

## 2.5.7 (2024-08-05)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.4 to 4.3.5

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/0b2256b8c012f0828dc542b3febcab082c67f72b...89ef406dd8d7e03cfd12d9e0a4a378f454709029)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8050f7e`](https://github.com/OZI-Project/ozi-templates/commit/8050f7edb56a9a5c15c9e3a900057733e29f8b90))

*  Bump ossf/scorecard-action from 2.3.3 to 2.4.0

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.3 to 2.4.0.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/dc50aa9510b46c811795eb24b2f1ba02a914e534...62b2cac7ed8198b15735ed49ab1e5cf35480ba46)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`a48a841`](https://github.com/OZI-Project/ozi-templates/commit/a48a841dc940323a4fada32d01e659b1edd14723))

*  Bump github/codeql-action from 3.25.14 to 3.25.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.14 to 3.25.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5cf07d8b700b67e235fbb65cbc84f69c0cf10464...afb54ba388a7dca6ecae48f608c4ff05ff4cc77a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`f3fd7a3`](https://github.com/OZI-Project/ozi-templates/commit/f3fd7a377e6a1cbcf822277648188ac3a4df78d0))


### Other


* perf: Update dependabot.yml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`d1d8d5c`](https://github.com/OZI-Project/ozi-templates/commit/d1d8d5c69984b3ec8975c58cfc0c003856c12473))

## 2.5.6 (2024-07-28)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e8d483d`](https://github.com/OZI-Project/ozi-templates/commit/e8d483da7b8c0bab1656d321126683b36549d3d7))

*  Bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`defebd0`](https://github.com/OZI-Project/ozi-templates/commit/defebd0ffcae9dd741aa347c1327308f1cb2648c))

*  Bump github/codeql-action from 3.25.13 to 3.25.14

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.13 to 3.25.14.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2d790406f505036ef40ecba973cc774a50395aac...5cf07d8b700b67e235fbb65cbc84f69c0cf10464)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c71cd07`](https://github.com/OZI-Project/ozi-templates/commit/c71cd077fe815fafdc75580daf10a4b02d7ac742))

*  Bump github/codeql-action from 3.25.12 to 3.25.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.12 to 3.25.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4fa2a7953630fd2f3fb380f21be14ede0169dd4f...2d790406f505036ef40ecba973cc774a50395aac)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`4e709c7`](https://github.com/OZI-Project/ozi-templates/commit/4e709c70ac5c53464e8b44089d26b9fe1419a2e9))


### Other


* feat: use ``ozi.version`` as key for wrapfile revision — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e1861b6`](https://github.com/OZI-Project/ozi-templates/commit/e1861b647294da22aafb9b0a76b889560ea9906a))

## 2.5.5 (2024-07-18)

## 2.5.4 (2024-07-18)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.8.1 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.1 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`66de119`](https://github.com/OZI-Project/ozi-templates/commit/66de119380298fdc9b9fc0995e2901170037b371))

*  Bump OZI-Project/checkpoint from 0.4.3 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.3 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.3...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`ffa7fed`](https://github.com/OZI-Project/ozi-templates/commit/ffa7fed787340d778c7dea479923b0ab313014df))

*  Bump OZI-Project/release from 0.6.6 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.6 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.6...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`40c39f6`](https://github.com/OZI-Project/ozi-templates/commit/40c39f64486d80886fd059ad3901a61de442ec9a))

*  Bump OZI-Project/draft from 0.3.5 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.5 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.5...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`00ed822`](https://github.com/OZI-Project/ozi-templates/commit/00ed822acc63f36c3f62eb553dda180c24a0945f))


### 📌 Pinned Dependencies

*  OZI.build&gt;=0.0.27 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`aec9c2e`](https://github.com/OZI-Project/ozi-templates/commit/aec9c2e1d32ddda1df2a63f574302239579aa998))

## 2.5.3 (2024-07-15)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.6.5 to 0.6.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.6.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.6.6)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`09bba10`](https://github.com/OZI-Project/ozi-templates/commit/09bba108706c0a37c13ba51ef1873b7ea83a91b9))

*  Bump OZI-Project/checkpoint from 0.4.2 to 0.4.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.4.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.4.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`95c0d15`](https://github.com/OZI-Project/ozi-templates/commit/95c0d15899ba8e7fd04ccdc98bdf021213b159e0))

*  Bump OZI-Project/draft from 0.3.4 to 0.3.5

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.4 to 0.3.5.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.4...0.3.5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1027de3`](https://github.com/OZI-Project/ozi-templates/commit/1027de31f885adfaec3c1ff7b65b26bc3d80fc98))

*  Bump OZI-Project/publish from 0.1.7 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.7 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.7...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9446b32`](https://github.com/OZI-Project/ozi-templates/commit/9446b32d93d4cf276d7ebb576c09de1729d081a0))

*  Bump actions/dependency-review-action from 4.3.3 to 4.3.4

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/72eb03d02c7872a771aacd928f3123ac62ad6d3a...5a2ce3f5b92ee19cbb1541a4984c76d921601d7c)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`77bc3af`](https://github.com/OZI-Project/ozi-templates/commit/77bc3af4418b26fd052ad461c422b7ab26d15fec))

*  Bump github/codeql-action from 3.25.11 to 3.25.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.11 to 3.25.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b611370bb5703a7efb587f9d136a52ea24c5c38c...4fa2a7953630fd2f3fb380f21be14ede0169dd4f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`002ccd5`](https://github.com/OZI-Project/ozi-templates/commit/002ccd5adc2b5f4c2a22dbdea69cc16ad5d6b70b))

## 2.5.2 (2024-07-08)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.3 to 0.3.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.3...0.3.4)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e07446b`](https://github.com/OZI-Project/ozi-templates/commit/e07446bdc7d4a5834e604757b93705743c6e14eb))

*  Bump OZI-Project/publish from 0.1.6 to 0.1.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.6...0.1.7)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b770bf8`](https://github.com/OZI-Project/ozi-templates/commit/b770bf8cc08fe44fa18ac9b6850f94572903c55a))

*  Bump actions/upload-artifact from 4.3.3 to 4.3.4

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65462800fd760344b1a7b4382951275a0abb4808...0b2256b8c012f0828dc542b3febcab082c67f72b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c673007`](https://github.com/OZI-Project/ozi-templates/commit/c673007c378d69e346a6c4a028b2a75843a80220))

## 2.5.1 (2024-07-08)


### 🐛 Fixed Bugs

* add subprojects templates to build — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c7d229d`](https://github.com/OZI-Project/ozi-templates/commit/c7d229dcc9cf63dd29dab0ff927cac8107a9d55a))

## 2.5.0 (2024-07-07)


### ✨ Implemented Features

*  update for OZI spec 0.5 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6363eaa`](https://github.com/OZI-Project/ozi-templates/commit/6363eaa0b3c35f3519add1b2f2cf37e2a283e85d))

## 2.4.9 (2024-07-04)


### 🚸 Improved Usability

*  add release pattern matching default OZI workflow to semantic_release config template — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`0351743`](https://github.com/OZI-Project/ozi-templates/commit/035174311c70af5986c96d1ce188d620b904ab04))

## 2.4.8 (2024-07-03)


### 🐛 Fixed Bugs

*  release patch fixes for names
([`790e648`](https://github.com/OZI-Project/ozi-templates/commit/790e648971a020f2c71095efdfae7ea5a5da7e70))


### Other


* fix: Non-lowercase and underscored name expected for ``project.name`` context — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e9feb82`](https://github.com/OZI-Project/ozi-templates/commit/e9feb82ded67eed301cc4b022ad09f82cb8c17a7))

* fix(CHANGELOG): add project name to heading

release
([`fb7dcb3`](https://github.com/OZI-Project/ozi-templates/commit/fb7dcb3ddbb64172ce989fa0790f891c152f1f41))

## 2.4.7 (2024-07-03)


### 🐛 Fixed Bugs

*  consistent CHANGELOG style, initial 0.0.0 entry no longer overwritten by semantic-release — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c42b863`](https://github.com/OZI-Project/ozi-templates/commit/c42b8634343566fe3ab633ffa789f04a1ec1cf0f))


### Other


* Update CHANGELOG.md.j2 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`727eb6c`](https://github.com/OZI-Project/ozi-templates/commit/727eb6ce0ead15df9202a6a8a30c642762b5b3b1))

## 2.4.6 (2024-07-03)


### 🐛 Fixed Bugs

*  fix duplicated changelog commit headings — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4e04403`](https://github.com/OZI-Project/ozi-templates/commit/4e04403ae80ac37cc64f4b9550fe292b81b661cd))

## 2.4.5 (2024-07-03)


### 🐛 Fixed Bugs

*  fix requirements.in render to properly ignore newlines — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2e04d1a`](https://github.com/OZI-Project/ozi-templates/commit/2e04d1a99bf41b732246896211b08dccfdafb6d1))


### 🚸 Improved Usability

*  remove CHANGELOG.md from build files — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b5a89ae`](https://github.com/OZI-Project/ozi-templates/commit/b5a89ae32d5c6c12188e2f7306a359cdef358599))

## 2.4.4 (2024-07-03)


### 🐛 Fixed Bugs

*  fix nesting issue in CHANGELOG template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`92a1954`](https://github.com/OZI-Project/ozi-templates/commit/92a1954eaa44197112abbd8760836b068849bd49))

*  fix changelog template
([`2c0936c`](https://github.com/OZI-Project/ozi-templates/commit/2c0936c9c8e1fda135acf5ceeafb8fc3f4a9b402))


### Other


* Update CHANGELOG.md.j2 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`ae69e8d`](https://github.com/OZI-Project/ozi-templates/commit/ae69e8d6df037bd2101879111f3159fd63d7c447))

## 2.4.3 (2024-07-03)


### 🐛 Fixed Bugs

*  escape raw jinja2 in changelog template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3473956`](https://github.com/OZI-Project/ozi-templates/commit/347395685a96db7d5beef7a678fa57e668b0a6d4))

## 2.4.2 (2024-07-02)


### 🚸 Improved Usability

* Update ``CHANGELOG.md.j2`` to replace gitmoji codes with unicode characters. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`afa3f4d`](https://github.com/OZI-Project/ozi-templates/commit/afa3f4d9cc32170cfa297cb80ea21c48353578b1))

## 2.4.1 (2024-07-02)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.10 to 3.25.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.10 to 3.25.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/23acc5c183826b7a8a97bce3cecc52db901f8251...b611370bb5703a7efb587f9d136a52ea24c5c38c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`84906bf`](https://github.com/OZI-Project/ozi-templates/commit/84906bf6a063545bac2567d810abc036918ecad9))


### 🚸 Improved Usability

* (license): add BlueOak-1.0.0 templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`888f02d`](https://github.com/OZI-Project/ozi-templates/commit/888f02d18a1297413b0ece695508aea549d80106))

## 2.4.0 (2024-07-01)


### ✨ Implemented Features

* (license): add CeCILL-B, CeCILL-C, MirOS, OGTSL, and UPL-1.0 support.

Also fixes unlicense. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`334da31`](https://github.com/OZI-Project/ozi-templates/commit/334da31a55bc845dfddbebde1f5acc635057a66c))

## 2.3.4 (2024-06-30)


### 🐛 Fixed Bugs

*  fix missing unlicense — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`eed9ec6`](https://github.com/OZI-Project/ozi-templates/commit/eed9ec690af111fc439d2f46bdf60f1a65f20492))

## 2.3.3 (2024-06-30)


### 🐛 Fixed Bugs

*  fix missing Eiffel and 0BSD license folders — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ca1ca00`](https://github.com/OZI-Project/ozi-templates/commit/ca1ca0094577a5b605a2c3b418090c91d1f671d0))

## 2.3.2 (2024-06-29)


### 🐛 Fixed Bugs

*  add missing Eiffel_Forum_License__EFL_ folder to install — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f129ef2`](https://github.com/OZI-Project/ozi-templates/commit/f129ef236951d1875d7d608681f7ca39f1b3bfde))

## 2.3.1 (2024-06-29)


### 🐛 Fixed Bugs

*  add missing EFL licenses — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f0fb24e`](https://github.com/OZI-Project/ozi-templates/commit/f0fb24e0146e741d0f2f43871b3a58c91e6cce87))

## 2.3.0 (2024-06-29)


### ✏️ Corrected Typos

*  missed comma — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`59c1242`](https://github.com/OZI-Project/ozi-templates/commit/59c124291c7db9bae8c5485763ffad1dea636cba))


### ✨ Implemented Features

* (license) add all supported license variants — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2927fa1`](https://github.com/OZI-Project/ozi-templates/commit/2927fa1db28dcc63c7893aae6ee199008279bd12))

## 2.2.0 (2024-06-28)


### 🐛 Fixed Bugs

*  add ``OSI Approved :: ... Unlicense ...`` templates. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4ec65b7`](https://github.com/OZI-Project/ozi-templates/commit/4ec65b70ddbe40717bab358c414a285b0f260249))


### ✨ Implemented Features

*  default to Unlicense for LicenseRef-Public-Domain — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`14b469f`](https://github.com/OZI-Project/ozi-templates/commit/14b469fa5bbcf21ff4eccfa70c1a20899a416dca))

## 2.1.2 (2024-06-21)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.2 to 0.3.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.2 to 0.3.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.2...0.3.3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`dec807f`](https://github.com/OZI-Project/ozi-templates/commit/dec807ff39d8b2438bc837c397e0f050cc0b4101))

*  Bump OZI-Project/publish from 0.1.5 to 0.1.6

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.5...0.1.6)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`3fe734d`](https://github.com/OZI-Project/ozi-templates/commit/3fe734d2ab68217309461dae0f6bdf462bdcc88a))


### 🐛 Fixed Bugs

*  parsed_commit_heading renamed to avoid rendering — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`9a8b8e1`](https://github.com/OZI-Project/ozi-templates/commit/9a8b8e17e31c6874da9be3ac82007d26db95efaa))

## 2.1.1 (2024-06-20)


### 🐛 Fixed Bugs

*  escape CHANGELOG and release notes templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4546e4e`](https://github.com/OZI-Project/ozi-templates/commit/4546e4e889b257bfd4fe861a1ebe6936929fe818))

## 2.1.0 (2024-06-20)


### 🐛 Fixed Bugs

* 📝 fix double escape in changelog — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a820edd`](https://github.com/OZI-Project/ozi-templates/commit/a820edd95fbea12c4c0be5198f474d07eb42f0d2))


### ✨ Implemented Features

*  add templates folder to build

The following templates are used by semantic-release:
- ``CHANGELOG.md.j2``
- ``.release_notes.md.j2``

``parsed_commit_heading.j2`` is included in both to render common commit headings. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fff61a8`](https://github.com/OZI-Project/ozi-templates/commit/fff61a8e5279e1905c1fc104c53f3f53a4069220))

## 2.0.8 (2024-06-20)


### 🐛 Fixed Bugs

*  update wrap address in template to OZI-Project — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`030351d`](https://github.com/OZI-Project/ozi-templates/commit/030351d8197881b454007790c237503e3478d58a))


### Other


* 📝 update CHANGELOG and release notes templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`26f02d0`](https://github.com/OZI-Project/ozi-templates/commit/26f02d078ce6ad4874f97c0cba16aa9ee382930d))

## 2.0.7 (2024-06-18)


### 🚸 Improved Usability

* CHANGELOG and release_notes templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fa3ebef`](https://github.com/OZI-Project/ozi-templates/commit/fa3ebefbb148b70150f26f90e90aff274df66178))

## 2.0.6 (2024-06-17)


### 🐛 Fixed Bugs

* (checkpoint.yml.j2): prerelease checkpoint no longer included by default — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`124bc74`](https://github.com/OZI-Project/ozi-templates/commit/124bc741ca57781492785fab45d6712eee0a2fd5))


### 🚸 Improved Usability

*  Create .gitattributes — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`cf0ba23`](https://github.com/OZI-Project/ozi-templates/commit/cf0ba231f2e911dccf5696c9d5749cc00052f346))

## 2.0.5 (2024-06-17)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.1 to 0.3.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.1 to 0.3.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.1...0.3.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`68a5674`](https://github.com/OZI-Project/ozi-templates/commit/68a56749f240cd2a18f42c9f7bb1e8907c1b240f))

*  Bump github/codeql-action from 3.25.3 to 3.25.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.3 to 3.25.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d39d31e687223d841ef683f52467bd88e9b21c14...23acc5c183826b7a8a97bce3cecc52db901f8251)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ff5472f`](https://github.com/OZI-Project/ozi-templates/commit/ff5472f9f2b8d10b48bdd4c1fe061da15699e1fe))

*  Bump ossf/scorecard-action from 2.3.1 to 2.3.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.1 to 2.3.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/0864cf19026789058feabb7e87baa5f140aac736...dc50aa9510b46c811795eb24b2f1ba02a914e534)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b8cc5cf`](https://github.com/OZI-Project/ozi-templates/commit/b8cc5cffb37316b48d63120564e0b4aca5224203))

*  Bump actions/dependency-review-action from 4.2.5 to 4.3.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.2.5 to 4.3.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5bbc3ba658137598168acb2ab73b21c432dd411b...72eb03d02c7872a771aacd928f3123ac62ad6d3a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`c1498bd`](https://github.com/OZI-Project/ozi-templates/commit/c1498bd797c36a2b03e5dc8a0f7adc5145425f21))

*  Bump step-security/harden-runner from 2.7.0 to 2.8.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.0 to 2.8.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/63c24ba6bd7ba022e95695ff85de572c04a18142...17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`bbc592e`](https://github.com/OZI-Project/ozi-templates/commit/bbc592eb025bdd61ee5003bd554b1f5c04b61702))

*  Bump OZI-Project/checkpoint from 0.1.5 to 0.4.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.5 to 0.4.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.1.5...0.4.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`1ad4dd1`](https://github.com/OZI-Project/ozi-templates/commit/1ad4dd1b02e628b79366f6da2e582bb7ed660dc8))

*  Bump actions/checkout from 4.1.4 to 4.1.7

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.4 to 4.1.7.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/0ad4b8fadaa221de15dcec353f45205ec38ea70b...692973e3d937129bcbf40652eb9f2f61becf3332)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`282d6b9`](https://github.com/OZI-Project/ozi-templates/commit/282d6b96d026d2285e7699169813d853715531d1))

## 2.0.4 (2024-06-17)


### 🐛 Fixed Bugs

*  fix PackageLoader path — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`888050d`](https://github.com/OZI-Project/ozi-templates/commit/888050d270d1ac02ba684ee837b3347d2f2cf310))

## 2.0.3 (2024-06-17)


### 🐛 Fixed Bugs

*  fix blastpipe reference in packageloader — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2be3d1a`](https://github.com/OZI-Project/ozi-templates/commit/2be3d1a98cd266f85f5fb8e464dc10112f091e27))

## 2.0.2 (2024-06-16)


### 🐛 Fixed Bugs

*  fix project module name
([`03f8b1e`](https://github.com/OZI-Project/ozi-templates/commit/03f8b1e630ebf02f513877248ac351436a047c15))

## 2.0.1 (2024-06-16)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release@0.6.5

Ignores wheel filenames in glob for sigstore. — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`bbe482d`](https://github.com/OZI-Project/ozi-templates/commit/bbe482da512ab78ea4c3ebcdc92a925f4e0525df))

*  bump OZI.build
([`843f161`](https://github.com/OZI-Project/ozi-templates/commit/843f161073077b5bfafcd4f052f9055e256182a2))


### 🐛 Fixed Bugs

*  OZI.build&gt;=0.0.26

parity with blastpipe 2024.11.10 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b57d4f6`](https://github.com/OZI-Project/ozi-templates/commit/b57d4f67aa1622ddb98ab89540b063f4924a1927))

*  project name
([`1aba880`](https://github.com/OZI-Project/ozi-templates/commit/1aba8809cef1d70bc97ff9497c65cad7b5466242))


### Other


* Update README — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`3efec29`](https://github.com/OZI-Project/ozi-templates/commit/3efec29e2c5efdd4745e202c631649b92f62b049))

* Update meson.build - fix project name — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`95719bf`](https://github.com/OZI-Project/ozi-templates/commit/95719bf0abdee4f4dc7c74a332d115868bf76c3a))

* Fix branch pattern — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`d221e61`](https://github.com/OZI-Project/ozi-templates/commit/d221e618bca32cdf51c7dd26bb58376825d0a05b))

## 2.0.0 (2024-06-16)


### 💥


*  version bump — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`52b4953`](https://github.com/OZI-Project/ozi-templates/commit/52b4953eaaf9427636b4112f5f7378678b2b0a50))

*  fix release strategy
([`e40ebfb`](https://github.com/OZI-Project/ozi-templates/commit/e40ebfb305a64a15aa02f6347d8cb04f633682c3))


### 🐛 Fixed Bugs

*  update to build version with normalized metadata — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2ccbd1c`](https://github.com/OZI-Project/ozi-templates/commit/2ccbd1c2f0860f690280129b812f9dcb29bf031c))

*  publish if needs.draft.outputs.drafted == &#39;true&#39; — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`244ddf4`](https://github.com/OZI-Project/ozi-templates/commit/244ddf4c8c74955689ec9a007efa6b09f9e75165))

*  fix repo name — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`959bab3`](https://github.com/OZI-Project/ozi-templates/commit/959bab31da5befd1e651ecb072fa7026e24cc9e9))

*  fix missing tag input to release — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a677875`](https://github.com/OZI-Project/ozi-templates/commit/a6778750e5546955daf528f22283bfb77c76fd93))

*  major_on_zero back to false — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8e76820`](https://github.com/OZI-Project/ozi-templates/commit/8e76820683aebe3f89f519ec2159ba815de7ca5c))

*  fix missing commit_parser_options — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ccf75ef`](https://github.com/OZI-Project/ozi-templates/commit/ccf75ef7f8ccc0cf99329f5a348dc45df84c536e))

*  fix commit_parser name — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`26b9b7a`](https://github.com/OZI-Project/ozi-templates/commit/26b9b7a61c31170e1e77b6532d9d3ef3448a8505))


### ✨ Implemented Features

*  bump version — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`83c01e5`](https://github.com/OZI-Project/ozi-templates/commit/83c01e5f8def35badc58f7b00bba58b2fa547c94))

*  revert angular commit parsing. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`1a8e395`](https://github.com/OZI-Project/ozi-templates/commit/1a8e3958989ed760de0494faef3c48797d13b3e4))


### Other


* Update pyproject.toml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`178143e`](https://github.com/OZI-Project/ozi-templates/commit/178143e956bb251585181c680d1278b99cc98650))

* Update pyproject.toml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`f4b6b38`](https://github.com/OZI-Project/ozi-templates/commit/f4b6b38ad98c1e22df02cf45c758fa7d664cd4ee))

* Update pyproject.toml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`63eb260`](https://github.com/OZI-Project/ozi-templates/commit/63eb260f9e4a916d80d226b890f385ee1fd463ad))

* fix(semantic-release): config ``major_on_zero = true`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e2e04ef`](https://github.com/OZI-Project/ozi-templates/commit/e2e04efdf3d1d93868d3d1653f547427e5b63b18))

* fix(readme-renderer): fix args to target readme copied during build — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`d7ed57f`](https://github.com/OZI-Project/ozi-templates/commit/d7ed57f81d679006b0cf8125ee92d68b541e15de))

* style(isort): import sort — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fad659c`](https://github.com/OZI-Project/ozi-templates/commit/fad659c29b487e507396522e5edbb08923444ca8))

* fix(dist-depends): restore requirements.in — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3586f0f`](https://github.com/OZI-Project/ozi-templates/commit/3586f0f033a1f0d52c680c7964a5ab3b1ec8b006))

* fix(imports): remove blastpipe references — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`97395ae`](https://github.com/OZI-Project/ozi-templates/commit/97395ae610647f20909152613dbd927447dc418b))

* fix(tests): add test_filter.py to build — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`9b99d3a`](https://github.com/OZI-Project/ozi-templates/commit/9b99d3a060de90f41f12509e68f5b50f12705a08))

* style(isort): sort imports — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6faeeff`](https://github.com/OZI-Project/ozi-templates/commit/6faeeffed15231f5f3ac6f2f8628e78b430081d6))

* Update pyproject.toml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`8dfad97`](https://github.com/OZI-Project/ozi-templates/commit/8dfad9728cb2934c388714f1e9a968000993dcd1))

* feat(package): mirror blastpipe 2024.11.7 ozi_templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2987d9c`](https://github.com/OZI-Project/ozi-templates/commit/2987d9c6b8ebc723ed3dc39334794c7fd764709a))

## 1.0.0 (2024-04-27)


### 💥


*  add load_environment() func — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`7cb9510`](https://github.com/OZI-Project/ozi-templates/commit/7cb951045f3855ab6a301ca52d536d96e4a3f0c0))


### 🐛 Fixed Bugs

*  fix release workflow outputs so publish is not skipped. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2ce8dd0`](https://github.com/OZI-Project/ozi-templates/commit/2ce8dd0f24f52f9c497dd9dd57be6bdcd917b010))

*  Fix publish workflow had ssh arguments still. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`77a8ede`](https://github.com/OZI-Project/ozi-templates/commit/77a8edef6915fc3324e0ac131500747a5a8d72f1))

*  fix name normalization in project and template.

Without normalization we get duplicate dist_info. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`d40e46a`](https://github.com/OZI-Project/ozi-templates/commit/d40e46ae36927546cca0fe76baa2c870ccd6a2a7))


### 🔥 Deleted Code or Files

*  delete template readme
([`33abd6c`](https://github.com/OZI-Project/ozi-templates/commit/33abd6c51075136fb8b40ba7c81e28a2b405f236))


### ✏️ Corrected Typos

*  correct project name
([`9df80d8`](https://github.com/OZI-Project/ozi-templates/commit/9df80d8511050ab6596f5b10f8d7dc41be0c0924))


### Other


* Initial clone of templates — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`a8370f9`](https://github.com/OZI-Project/ozi-templates/commit/a8370f94cf621f3035ce6ac956fe96a752b005d2))

* Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`54566b3`](https://github.com/OZI-Project/ozi-templates/commit/54566b3f685b0a8757105c1ff8177eabdbe61d3e))

* Initial commit
([`6df66d3`](https://github.com/OZI-Project/ozi-templates/commit/6df66d3a74d25f7e06bb573249b8c065155b9358))
